@@ -26,7 +26,15 @@ public final class ApidbVersionConstants {
 		"20120214210114", "20120219161649", "20120318201948",
 		"20120328090602", "20120404205604", "20120808231205",
 		"20121005195010", "20121012044047", "20121119165817",
-		"20121202155309", "20121203124841", "20130328184137"
+		"20121202155309", "20121203124841", "20130328184137",
+		"20131212124700", "20140115192822", "20140117185510",
+		"20140210003018", "20140507110937", "20140519141742",
+		"20150110152606", "20150111192335", "20150222101847",
+		"20150818224516", "20160822153055", "20161002153425",
+		"20161011010929", "20170222134109", "20180204153242",
+		"20181020114000", "20181031113522", "20190518115041",
+		"20190623093642", "20190702193519", "20190716173946",
+		"20191120140058"
 	};
 
 	/**
