@@ -42,7 +42,7 @@ public class MultipleSourceIterator<T> implements ReleasableIterator<T> {
 			if (sources.get(0).hasNext()) {
 				return true;
 			} else {
-				sources.remove(0).release();
+				sources.remove(0).close();
 			}
 		}
 		
@@ -76,9 +76,9 @@ public class MultipleSourceIterator<T> implements ReleasableIterator<T> {
 	 * {@inheritDoc}
 	 */
 	@Override
-	public void release() {
+	public void close() {
 		for (ReleasableIterator<T> source : sources) {
-			source.release();
+			source.close();
 		}
 	}
 	
