@@ -362,20 +362,4 @@ public class DatabaseContext implements AutoCloseable {
 			connection = null;
 		}
 	}
-	
-	
-	/**
-	 * Enforces cleanup of any remaining resources during garbage collection.
-	 * This is a safeguard and should not be required if release is called
-	 * appropriately.
-	 * 
-	 * @throws Throwable
-	 *             if an unexpected problem occurs during finalization.
-	 */
-	@Override
-	protected void finalize() throws Throwable {
-		close();
-		
-		super.finalize();
-	}
 }
