@@ -1,8 +1,6 @@
 // This software is released into the Public Domain.  See copying.txt for details.
 package org.openstreetmap.osmosis.pgsnapshot.v0_6;
 
-import org.openstreetmap.osmosis.core.database.DatabaseLoginCredentials;
-import org.openstreetmap.osmosis.core.database.DatabasePreferences;
 import org.openstreetmap.osmosis.core.database.DatabaseTaskManagerFactory;
 import org.openstreetmap.osmosis.core.pipeline.common.TaskConfiguration;
 import org.openstreetmap.osmosis.core.pipeline.common.TaskManager;
@@ -18,27 +16,24 @@ public class PostgreSqlChangeWriterFactory extends DatabaseTaskManagerFactory {
 	
 	private static final String ARG_KEEP_INVALID_WAYS = "keepInvalidWays";
 	private static final boolean DEFAULT_KEEP_INVALID_WAYS = true;
+	private static final String ARG_LOGGING = "logging";
+	private static final boolean DEFAULT_LOGGING = false;
 	
 	/**
 	 * {@inheritDoc}
 	 */
 	@Override
 	protected TaskManager createTaskManagerImpl(TaskConfiguration taskConfig) {
-		DatabaseLoginCredentials loginCredentials;
-		DatabasePreferences preferences;
-		
-		// Get the task arguments.
-		loginCredentials = getDatabaseLoginCredentials(taskConfig);
-		preferences = getDatabasePreferences(taskConfig);
-		
 		boolean keepInvalidWays = getBooleanArgument(taskConfig, ARG_KEEP_INVALID_WAYS, DEFAULT_KEEP_INVALID_WAYS);
+		boolean logging = getBooleanArgument(taskConfig, ARG_LOGGING, DEFAULT_LOGGING);
 		
 		return new ChangeSinkManager(
 			taskConfig.getId(),
 			new PostgreSqlChangeWriter(
-				loginCredentials,
-				preferences,
-				keepInvalidWays
+				getDatabaseLoginCredentials(taskConfig),
+				getDatabasePreferences(taskConfig),
+				keepInvalidWays,
+				logging
 			),
 			taskConfig.getPipeArgs()
 		);
