@@ -3,7 +3,6 @@ package org.openstreetmap.osmosis.pgsnapshot.v0_6;
 
 import java.util.logging.Logger;
 
-import org.openstreetmap.osmosis.core.database.DatabaseLocker;
 import org.openstreetmap.osmosis.core.database.DatabaseLoginCredentials;
 import org.openstreetmap.osmosis.core.database.DatabasePreferences;
 import org.openstreetmap.osmosis.core.task.common.RunnableTask;
@@ -21,6 +20,7 @@ public class PostgreSqlTruncator implements RunnableTask {
 	
 	private static final Logger LOG = Logger.getLogger(PostgreSqlTruncator.class.getName());
 	
+	
 	// These tables will be truncated.
 	private static final String[] SQL_TABLE_NAMES = {
 		"actions",
@@ -30,9 +30,10 @@ public class PostgreSqlTruncator implements RunnableTask {
 		"relations", "relation_tags", "relation_members"
 	};
 	
+	
 	private DatabaseContext dbCtx;
 	private SchemaVersionValidator schemaVersionValidator;
-	private DatabaseLocker locker;
+	
 	
 	/**
 	 * Creates a new instance.
@@ -44,10 +45,11 @@ public class PostgreSqlTruncator implements RunnableTask {
 	 */
 	public PostgreSqlTruncator(DatabaseLoginCredentials loginCredentials, DatabasePreferences preferences) {
 		dbCtx = new DatabaseContext(loginCredentials);
-		this.locker = new DatabaseLocker(new DatabaseContext(loginCredentials).getDataSource(), true);
+		
 		schemaVersionValidator = new SchemaVersionValidator(dbCtx.getJdbcTemplate(), preferences);
 	}
 	
+	
 	/**
 	 * Truncates all data from the database.
 	 */
@@ -56,7 +58,7 @@ public class PostgreSqlTruncator implements RunnableTask {
 			schemaVersionValidator.validateVersion(PostgreSqlVersionConstants.SCHEMA_VERSION);
 			
 			dbCtx.beginTransaction();
-			this.locker.lockDatabase(this.getClass().getSimpleName());
+			
 			LOG.fine("Truncating tables.");
 			for (int i = 0; i < SQL_TABLE_NAMES.length; i++) {
 				if (dbCtx.doesTableExist(SQL_TABLE_NAMES[i])) {
@@ -75,7 +77,6 @@ public class PostgreSqlTruncator implements RunnableTask {
 			LOG.fine("Complete.");
 			
 		} finally {
-			this.locker.unlockDatabase();
 			dbCtx.close();
 		}
 	}
