@@ -4,6 +4,10 @@ package org.openstreetmap.osmosis.pgsnapshot.v0_6.impl;
 import java.util.ArrayList;
 import java.util.List;
 
+import net.postgis.jdbc.geometry.LineString;
+import net.postgis.jdbc.geometry.LinearRing;
+import net.postgis.jdbc.geometry.Point;
+import net.postgis.jdbc.geometry.Polygon;
 import org.openstreetmap.osmosis.core.OsmosisRuntimeException;
 import org.openstreetmap.osmosis.core.domain.v0_6.Node;
 import org.openstreetmap.osmosis.core.domain.v0_6.Way;
@@ -15,11 +19,6 @@ import org.openstreetmap.osmosis.pgsnapshot.common.NodeLocation;
 import org.openstreetmap.osmosis.pgsnapshot.common.NodeLocationStore;
 import org.openstreetmap.osmosis.pgsnapshot.common.NodeLocationStoreType;
 import org.openstreetmap.osmosis.pgsnapshot.common.PersistentNodeLocationStore;
-import org.postgis.LineString;
-import org.postgis.LinearRing;
-import org.postgis.Point;
-import org.postgis.Polygon;
-
 
 /**
  * Caches a set of node latitudes and longitudes and uses these to calculate the
@@ -192,9 +191,12 @@ public class WayGeometryBuilder implements Closeable {
 	 * 
 	 * @param way
 	 *            The way to create the linestring for.
+	 * @param enableKeepPartialLinestring
+	 *            If true, the way linestring is build even on invalid or missing
+	 *            nodes.
 	 * @return The linestring representing the way.
 	 */
-	public LineString createWayLinestring(Way way) {
+	public LineString createWayLinestring(Way way, boolean enableKeepPartialLinestring) {
 		List<Point> linePoints;
 		
 		linePoints = new ArrayList<Point>();
@@ -206,9 +208,17 @@ public class WayGeometryBuilder implements Closeable {
 			if (nodeLocation.isValid()) {
 				linePoints.add(new Point(nodeLocation.getLongitude(), nodeLocation.getLatitude()));
 			} else {
-				return null;
+				if (!enableKeepPartialLinestring) {
+					return null;
+				}
 			}
 		}
+		
+		if (enableKeepPartialLinestring && way.isClosed() && linePoints.size() > 1
+			&& !linePoints.get(0).equals(linePoints.get(linePoints.size() - 1))) {
+			linePoints.add(linePoints.get(0));
+		}
+		
 		return createLinestring(linePoints);
 	}
 	
