@@ -32,9 +32,11 @@ public class ReplicationDownloader extends BaseReplicationDownloader implements
 	 * 
 	 * @param workingDirectory
 	 *            The directory containing configuration and tracking files.
+	 * @param single
+	 * 			  Set to true if you want to only replicate a single diff file from the server
 	 */
-	public ReplicationDownloader(File workingDirectory) {
-		super(workingDirectory);
+	public ReplicationDownloader(File workingDirectory, boolean single) {
+		super(workingDirectory, single);
 		
 		// We will sort all contents prior to sending to the sink. This adds overhead that may not
 		// always be required, but provides consistent behaviour.
