@@ -11,21 +11,26 @@ public enum BoundRemovedAction {
 	/**
 	 * Continue processing quietly.
 	 */
-	Ignore ("ignore"),
+	Ignore("ignore"),
 	
 	/**
 	 * Continue processing but emit a warning to the log.
 	 */
-	Warn ("warn"),
+	Warn("warn"),
 	
 	/**
 	 * Stop processing and emit an error message to the log.
 	 */
-	Fail ("fail");
+	Fail("fail");
 	
 	private final String keyword;
-	
-	private BoundRemovedAction(String keyword) {
+
+	/**
+	 * Create a new instance.
+	 *
+	 * @param keyword The string representation of this enum instance.
+	 */
+	BoundRemovedAction(String keyword) {
 		this.keyword = keyword;
 	}
 	
