@@ -7,6 +7,6 @@ import java.util.Map;
 
 public interface Output {
 
-	void apply(Map<String, String> originalTags, Map<String, String> tags, Collection<Match> matches);
+	void apply(Map<String, String> originalTags, Map<String, String> tags, Collection<Match> matches, Map<String, DataSource> dataSources);
 
 }
